.. _spkg_polytopes_db_4d:

polytopes_db_4d: Database of 4-dimensional reflexive polytopes
==============================================================

Description
-----------

This package contains the database of 4-d reflexive polytopes with Hodge
numbers as index.

Based on the original list by Maximilian Kreuzer and Harald Skarke using
their software PALP.

License
-------

GPL v2+

SPKG Maintainers
----------------

Volker Braun <vbraun.name@gmail.com>



Type
----

optional


Dependencies
------------



Version Information
-------------------

package-version.txt::

    1.0

Equivalent System Packages
--------------------------

# See https://repology.org/project/polytopes-db-4d/versions

However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
